declare namespace _exports {
    export { DoMarkdownItOptions };
}
declare const _exports: import('markdown-it').PluginWithOptions<DoMarkdownItOptions>;
export = _exports;
type DoMarkdownItOptions = {
    /**
     * Disable highlight syntax.
     */
    highlight?: false;
    /**
     * Disable user mentions, or set options for the feature.
     */
    user_mention?: false | import('./rules/user_mention').UserMentionOptions;
    /**
     * Disable HTML comment stripping, or set options for the feature.
     */
    html_comment?: false | import('./rules/html_comment').HtmlCommentOptions;
    /**
     * Disable image captions.
     */
    image_caption?: false;
    /**
     * Disable table wrapper, or set options for the feature.
     */
    table_wrapper?: false | import('./rules/table_wrapper').TableWrapperOptions;
    /**
     * Disable callout block syntax, or set options for the feature.
     */
    callout?: false | import('./rules/embeds/callout').CalloutOptions;
    /**
     * Disable RSVP buttons, or set options for the feature.
     */
    rsvp_button?: false | import('./rules/embeds/rsvp_button').RsvpButtonOptions;
    /**
     * Disable terminal buttons, or set options for the feature.
     */
    terminal_button?: false | import('./rules/embeds/terminal_button').TerminalButtonOptions;
    /**
     * Disable columns, or set options for the feature.
     */
    columns?: false | import('./rules/embeds/columns').ColumnsOptions;
    /**
     * Disable details.
     */
    details?: false;
    /**
     * Disable glob embeds.
     */
    glob?: false;
    /**
     * Disable DNS lookup embeds.
     */
    dns?: false;
    /**
     * Disable Asciinema embeds.
     */
    asciinema?: false;
    /**
     * Disable CodePen embeds.
     */
    codepen?: false;
    /**
     * Disable Glitch embeds.
     */
    glitch?: false;
    /**
     * Disable CanIUse embeds.
     */
    caniuse?: false;
    /**
     * Disable YouTube embeds.
     */
    youtube?: false;
    /**
     * Disable Wistia embeds.
     */
    wistia?: false;
    /**
     * Disable Vimeo embeds.
     */
    vimeo?: false;
    /**
     * Disable Twitter embeds.
     */
    twitter?: false;
    /**
     * Disable Instagram embeds.
     */
    instagram?: false;
    /**
     * Disable Slideshow embeds.
     */
    slideshow?: false;
    /**
     * Disable Image Compare embeds.
     */
    compare?: false;
    /**
     * Disable underline syntax.
     */
    underline?: false;
    /**
     * Disable fence labels, or set options for the feature.
     */
    fence_label?: false | import('./modifiers/fence_label').FenceLabelOptions;
    /**
     * Disable fence secondary labels, or set options for the feature.
     */
    fence_secondary_label?: false | import('./modifiers/fence_secondary_label').FenceSecondaryLabelOptions;
    /**
     * Disable fence environments, or set options for the feature.
     */
    fence_environment?: false | import('./modifiers/fence_environment').FenceEnvironmentOptions;
    /**
     * Disable fence prefixes, or set options for the feature.
     */
    fence_prefix?: false | import('./modifiers/fence_prefix').FencePrefixOptions;
    /**
     * Disable fence pre attributes.
     */
    fence_pre_attrs?: false;
    /**
     * Disable fence class filtering, or set options for the feature.
     */
    fence_classes?: false | import('./modifiers/fence_classes').FenceClassesOptions;
    /**
     * Disable Ids on headings, or set options for the feature.
     */
    heading_id?: false | import('./modifiers/heading_id').HeadingIdOptions;
    /**
     * Disable image settings syntax, or set options for the feature.
     */
    image_settings?: false | import('./modifiers/image_settings').ImageSettingsOptions;
    /**
     * Disable Prism highlighting, or set options for the feature.
     */
    prismjs?: false | import('./modifiers/prismjs').PrismJsOptions;
    /**
     * Enable custom link attributes by setting options for the feature.
     */
    link_attributes?: import('./modifiers/link_attributes').LinkAttributesOptions;
    /**
     * Enable token filtering by setting options for the feature.
     */
    limit_tokens?: import('./rules/limit_tokens').LimitTokensOptions;
};
